
function [] = mcpkineticQuartet(varargin)
% Function that evaluate the kynetic energy of mocap data using the Dempster Model.
% Every subject need at least 13 marker if there are more increment the value of the third input.
%
% Marker Disposition:
%
% 1- LFHD left head
% 2- RFHD right head
% 3- OZ   back head
% 4- C7   neck
% 5- LSHO left shoulder
% 6- RSHO right shoulder
% 7- LELB left elbow
% 8- RELB right elbow
% 9- LWRB left wristband
% 10- RWRB right wristband
% 11- SACR back
% 12- LASI left hip
% 13- RASI right hip
%
%
% Input:
%
% 1- Directory containing the c3d files to elaborate
% 2- Directory in which you want save the result (graphical and in .m format)
% 3- How many marker you have to discard for analyze the next subject
% 4- Number of musician to extract[start,end]
% 5- onset correspond to two matrix, to trim file according to onset and offset found in QUARTETsegbase function
% 6- offset
% OPTIONAL
% 7- Directory containing the smpte files wav format
% 8- fps of smpte files
% Example:
%

%*******************
loadfile=varargin{1};
savefile=varargin{2};
numbody=varargin{3};
oronset=varargin{4};
oroffset=varargin{5};
if length(varargin)==7
    loadsmpte=varargin{6};
    filesmpte=dir(fullfile(varargin{6}, '*.wav'));
    fpsmpte=varargin{7};
end

% load file
files = dir(fullfile(loadfile, '*.c3d'));

markersname={'LFHD';'RFHD' ;'OZ'; 'C7' ; 'LSHO'; 'RSHO';'LELB'; 'RELB';'LWRB'; 'RWRB'; 'SACR'; 'LASI';'RASI'};


for k=1:length(files)
    
    %Uncomment for normal mocap data without May 2011 Bug
    %********************************************%
    d=mcread([loadfile files(k).name]);   %
    %********************************************%
    
    % fills gaps due to missing data through linear interpolation
    d1 = mcfillgaps(d, 'fillall');
    
    [~, name, ~] = fileparts([loadfile files(k).name]);
    
    
    if length(varargin)==7
        secon=oronset(:,((k-1)*4)+1:k*4);
        secoff=oroffset(:,((k-1)*4)+1:k*4);
        onset=SMPTEtoSec([loadsmpte filesmpte(k).name],fpsmpte,secon,secoff);
        offset=SMPTEtoSec([loadsmpte filesmpte(k).name],fpsmpte,secoff,secon);
    end
    
    mkdir([savefile '/' name]);
    
    
    
    
    subsegindex=size(onset,1);% size of onset/offset matrix ie start and end of each segment
    for i=1:subsegindex
        
        if length(varargin)==7
            d2=mctrim(d1,onset(i),offset(i),'sec');
        else
            d2=mctrim(d1,onset(i),offset(i),'frame');
        end
        
        %********************************************%
       
        
        %body counter
        body=numbody(1);
        
        while body<=numbody(2)
            
            body
            
            %marker
            
            prefix=['S0' int2str(body) '_'];
            markersname2=strcat(prefix,markersname);
           
            
            %getting only meaningful marker
            %d3=mcgetmarker(d2,[marker marker+1 marker+2 marker+3 marker+4 marker+5 marker+6 marker+7 marker+8 marker+9 marker+10 marker+11 marker+12]);
            d3=mcgetmarkerfromname(d2,markersname2);      
            
            % fills gaps due to missing data through linear interpolation
            d3 = mcfillgaps(d3, 'fillall');
            
            %the first thing to do is to convert the mocap data to a joint
            %structure
            m2jpar=mcinitm2jpar;
            
            %fill the joint structure with the needit data
            
            %insert the numbers of marker in the structure
            m2jpar.nMarkers=11;
            
            %cell structure containing, for each joint, the numbers of the markers whose centroid
            %defines the location of that joint; for instance, if markerNum{k} = [m1 m2 m3 m4],
            %the location of joint k is calculated as the centroid of markers m1, m2, m3, and m4
            m2jpar.markerNum={[1 2 3] 4 5 6 7 8 9 10 [11 12 13] 12 13 };
            
            %cell structure containing the names of the joints
            % [1 2 3]  4      5             6         7         8       9        10      11     12     13
            %'head','neck','lshoulder','rshoulder','lelbow','relbow','lwrist','rwrist','root','lhip','rhip'
            m2jpar.markerName={'HD','C7','LSHO','RSHO','LELB','RELB','LWRB','RWRB','ROOT','LASI','RASI'};
            
            %Initialises the parameter structure for joint-to-segment mapping.
            j2spar=mcinitj2spar;
            
            
            j2spar.rootMarker=9;
            j2spar.frontalPlane=[2 10 11];
            
            %vector containing the number of the parent joint (proximal joint in kinematic chain) of
            %each joint; zero means no parent joint
            %remember the sequence of joint:
            %'head','neck','lshoulder','rshoulder','lelbow','relbow','Lwrist','Rwrist','root','rhip','lhip'
            %this means that the head is linked with the neck, the neck with
            %the back, the back it's the root marker so it hasn't any parent
            %joint,rhip and lhip are linked with the back the shooulders with
            %the neck, relbow is linked to rshoulder, rwrist is linked to
            %rshoulder, lelbow is linked to lshoulder and lwrist is linked with
            %lelbow
            j2spar.parent=[2 9 2 2 3 4 5 6 0 9 9];
            
            
            %cell structure containing the names of each segment
            j2spar.segmentName={'HD','C7','LSHO','RSHO','LELB','RELB','LWRB','RWRB','ROOT','LASI','RASI'};
            
            % The marker-to-joint conversion is carried out like this:
            d12j = mcm2j(d3, m2jpar);
            
            
            %%%%%%%%%%%%%%%%%%%%%%%%%%%%% VISUALIZE BODY-SEGMENT MODEL OF THE MUSICIAN
            %         par=mcinitanimpar;
            %         % DEFINE parameters
            %         par.conn=[1 2;2 9;3 2;3 5;4 2;4 6;7 5;8 6;10 9;11 9];
            %         par.colors = 'wbgcr'; %wkkkk
            %         par.showmnum = 1;
            %         par.msize=6;
            %         par.az=90;
            %         mcplotframe(d12j,1, par);
            %         set(gcf,'Position',[40 50 400 300])
            %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            
            % The next step is to make a joint-to-segment transformation.
            % The parameters needed for this are in the variable j2spar.
            d12s = mcj2s(d12j, j2spar);
            
            % The parameters for each body segment can be obtained using the
            % function mcgetsegmpar:
            % The second argument in the function call associates each body segment in
            % walk1j and walk1s with a segment type.
            % Segment number values for model 'Dempster' are as follows: no parameter=0,
            % hand=1, forearm=2, upper arm=3, forearm and hand=4, upper extremity=5,
            % foot=6, leg=7, thigh=8, lower extremity=9, head=10, shoulder=11, thorax=12,
            % abdomen=13, pelvis=14, thorax and abdomen=15, abdomen and pelvis=16,
            % trunk=17, head, arms and trunk (to glenohumeral joint)=18, head, arms
            % and trunk (to mid-rib)=19.
            
            % For instance, the third component, 8, tells that the body segment whose
            % distal joint is joint number 3, is a 'thigh'.
            spar = mcgetsegmpar('Dempster',[10 0 11 11 3 3 2 2 12 0 0]);
            
            %normalize data
            % e.g., NormHeadPost=sqrt(HeadPostXYZ(:,1).^2)+(HeadPostXYZ(:,2).^2)+(HeadPostXYZ(:,3).^2);
            
            % The translational and rotational energy for each body segment
            % can be calculated as follows:
            
            [trans, roto] = mckinenergy(d12j, d12s, spar);
            
            % The total translational energy can be plotted as follows:
            
            %         plotobj=figure;
            %         set(gcf,'Position',[40 50 400 300])
            %         plot((1:d2.nFrames)/d2.freq, sum(trans,2));
            %         xlabel('Time / s')
            %         ylabel('Translational energy / W')
            %
            index_num=num2str(body,'%1d');
            %
            index_subseg=num2str(i,'%1d');
            %
            %         print(plotobj,'-dpng', [savefile name '_' index_num '_' index_subseg '.png'])
            mkdir([savefile '/' name '/' index_num]);
            mkdir([savefile '/' name '/' index_num '/' 'trans/']);
            mkdir([savefile '/' name '/' index_num '/' 'roto/']);
            
            dlmwrite([savefile '/' name '/' index_num '/' 'trans/' name '_trans_'  index_num '_' index_subseg '.m'],trans);
            dlmwrite([savefile '/' name '/' index_num '/' 'roto/' name '_roto_'  index_num '_' index_subseg '.m'],roto);
            
            
            body=body+1;
        end
        
        
    end
    
    %body counter
    body=numbody(1);
    
    while body<=numbody(2)
        index_num=num2str(body,'%1d');
        
        SiempreRead([savefile '/' name '/' index_num '/' 'trans/'],[savefile '/' name '/' index_num '/' 'trans/']);
        SiempreRead([savefile '/' name '/' index_num '/' 'roto/'],[savefile '/' name '/' index_num '/' 'roto/']);
        body=body+1;
    end
    
end


